import { html, ref, when } from '@microsoft/fast-element';
export const previewComponents = (prefix) => html `
  <template>
    <${prefix}-design-system-provider ${ref('provider')}>
      <div class="wrapper">
        <div class="column">
          <div class="row">
            <div class="column">
              <${prefix}-breadcrumb role="navigation">
                <${prefix}-breadcrumb-item href="#">Item 1</${prefix}-breadcrumb-item>
                <${prefix}-breadcrumb-item href="#">Item 2</${prefix}-breadcrumb-item>
                <${prefix}-breadcrumb-item>Item 3</${prefix}-breadcrumb-item>
              </${prefix}-breadcrumb>
            </div>
            <div class="column">
              <${prefix}-button href="#" :appearance="${(x) => x.buttonAppearanceAccent}">Button</${prefix}-button>
              <${prefix}-button href="#" :appearance="${(x) => x.buttonAppearanceNeutral}">Button</${prefix}-button>
              <${prefix}-button href="#" :appearance="${(x) => x.buttonAppearanceOutline}">Button</${prefix}-button>
            </div>
          </div>

          <div class="row">
            <div class="column">
              <${prefix}-radio-group role="radiogroup" orientation="horizontal">
                <${prefix}-radio
                  checked
                  role="radio"
                  aria-checked="true"
                  aria-required="false"
                  aria-disabled="false"
                  tabindex="0"
                >
                  Radio 1
                </${prefix}-radio>
                <${prefix}-radio
                  role="radio"
                  aria-checked="false"
                  aria-required="false"
                  aria-disabled="false"
                  tabindex="-1"
                >
                  Radio 2
                </${prefix}-radio>
              </${prefix}-radio-group>
            </div>
            <div class="column">
              <${prefix}-checkbox
                role="checkbox"
                checked
                aria-checked="true"
                aria-required="false"
                aria-disabled="false"
                tabindex="0"
              >
                Checkbox
              </${prefix}-checkbox>
              <${prefix}-checkbox
                role="checkbox"
                aria-checked="false"
                aria-required="false"
                aria-disabled="false"
                tabindex="0"
              >
                Checkbox
              </${prefix}-checkbox>
            </div>
          </div>

          <div class="row">
            <div class="column">
              <${prefix}-text-field
                placeholder="Text field"
                aria-label="Example text field"
                type="text"
              ></${prefix}-text-field>
            </div>
            <div class="column">
              <${prefix}-button ${ref('showDialogTrigger')} appearance="${(x) => x.buttonAppearanceAccent}">Show Modal</${prefix}-button>
              <${prefix}-flipper
                role="button"
                tabindex="-1"
                class="previous"
                aria-hidden="true"
                direction="previous"
              ></${prefix}-flipper>
              <${prefix}-flipper
                role="button"
                tabindex="-1"
                class="next"
                aria-hidden="true"
                direction="next"
              ></${prefix}-flipper>
              <${prefix}-switch
                role="switch"
                checked
                aria-checked="true"
                aria-disabled="false"
                tabindex="0"
              ></${prefix}-switch>

              <${prefix}-modal ${ref('modal')}>
                <h5 slot="top">Modal Title</h5>
                <p>
                  Lorem ipsum dolor sit amet consectetur adipisicing elit. Quis similique iste ab sed
                  voluptatem ut suscipit tenetur distinctio? Quo est debitis pariatur qui quisquam
                  repudiandae at atque et quibusdam rerum, reprehenderit sed laborum officiis
                  distinctio dolorum temporibus aperiam dolor consequatur perferendis aspernatur fugit
                  repellendus asperiores, voluptas illo? Voluptatum, atque quidem?
                </p>
                <${prefix}-button ${ref('closeDialogTrigger')} appearance="${(x) => x.buttonAppearanceAccent}" slot="bottom">Close</${prefix}-button>
              </${prefix}-modal>
            </div>
          </div>

          <div class="row">
            <div class="column">
              <${prefix}-slider
                role="slider"
                class="horizontal"
                tabindex="0"
                aria-valuenow="5"
                aria-valuemin="0"
                aria-valuemax="10"
                aria-orientation="horizontal"
                min="0"
                max="10"
                step="1"
                orientation="horizontal"
                mode="single-value"
              ></${prefix}-slider>
            </div>
            <div class="column">
              <${prefix}-combobox autocomplete="both">
                <${prefix}-option>Christopher Eccleston</${prefix}-option>
                <${prefix}-option>David Tenant</${prefix}-option>
                <${prefix}-option>Matt Smith</${prefix}-option>
                <${prefix}-option>Peter Capaldi</${prefix}-option>
                <${prefix}-option>Jodie Whittaker</${prefix}-option>
              </${prefix}-combobox>
            </div>
          </div>

          <div class="row">
            ${when((x) => x.prefix !== 'zero', html `
                <div class="column">
                  <${prefix}-accordion expand-mode="single">
                    <${prefix}-accordion-item slot="item" id="accordion-1" expanded="" class="expanded">
                      Accordion one content
                      <div slot="heading">Accordion one</div>
                    </${prefix}-accordion-item>
                    <${prefix}-accordion-item slot="item" id="accordion-2">
                      Accordion two content
                      <div slot="heading">Accordion two</div>
                    </${prefix}-accordion-item>
                    <${prefix}-accordion-item slot="item" id="accordion-3">
                      Accordion three content
                      <div slot="heading">Accordion three</div>
                    </${prefix}-accordion-item>
                  </${prefix}-accordion>
                </div>
              `)}
            
            <div class="column">
              <${prefix}-tree-view role="tree">
                <${prefix}-tree-item
                  role="treeitem"
                  tabindex="0"
                  aria-expanded="true"
                  expanded
                  selected
                  class="nested"
                >
                  Tree item 1
                  <${prefix}-tree-item slot="item" role="treeitem">Tree item 1 - 1</${prefix}-tree-item>
                </${prefix}-tree-item>
                <${prefix}-tree-item role="treeitem" tabindex="0" aria-expanded="false" class="nested">
                  Tree item 2
                  <${prefix}-tree-item slot="item" role="treeitem">Tree item 2 - 1</${prefix}-tree-item>
                </${prefix}-tree-item>
                <${prefix}-tree-item role="treeitem" class="nested">Tree item 3</${prefix}-tree-item>
              </${prefix}-tree-view>
            </div>
          </div>

          <div class="row">
            <div class="column">
              <${prefix}-progress role="progressbar"></${prefix}-progress>
            </div>
            <div class="column">
              <${prefix}-progress-ring role="progressbar"></${prefix}-progress-ring>
            </div>
          </div>
        </div>
      </div>
    </${prefix}-design-system-provider>
  </template>
`;
export const PreviewComponentsTemplate = html `
  ${(x) => previewComponents(x.prefix)}
`;
